Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/browser.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/browser.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/browser.py	(revision 14178)
@@ -21,5 +21,5 @@
 from waeup.ikoba.customers.browser import (
     PDFContractSlip, CustomerBaseEditFormPage)
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.uniben.interfaces import MessageFactory as _
 
 class PDFContractSlip(PDFContractSlip):
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/contracts.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/contracts.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/contracts.py	(revision 14178)
@@ -26,6 +26,6 @@
 from waeup.ikoba.customers.interfaces import ICustomerNavigation
 from waeup.ikoba.customers.contracts import ContractBase
-from ikobacustom.skeleton.interfaces import MessageFactory as _
-from ikobacustom.skeleton.customers.interfaces import (
+from ikobacustom.uniben.interfaces import MessageFactory as _
+from ikobacustom.uniben.customers.interfaces import (
     ISkeletonContract, ISkeletonContractEdit, ISkeletonContractProcess,
     ISkeletonContractOfficialUse)
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/customer.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/customer.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/customer.py	(revision 14178)
@@ -25,6 +25,6 @@
 from waeup.ikoba.customers.customer import Customer
 from waeup.ikoba.customers.interfaces import ICustomerNavigation
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomer
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.uniben.customers.interfaces import ISkeletonCustomer
+from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
@@ -46,6 +46,6 @@
     grok.implements(IFactory)
     grok.name(u'waeup.Customer')
-    title = u"Create a new skeleton customer.",
-    description = u"This factory instantiates new skeleton customer instances."
+    title = u"Create a new uniben customer.",
+    description = u"This factory instantiates new uniben customer instances."
 
     def __call__(self, *args, **kw):
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/documents.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/documents.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/documents.py	(revision 14178)
@@ -25,6 +25,6 @@
 from waeup.ikoba.customers.interfaces import ICustomerNavigation
 from waeup.ikoba.customers.documents import CustomerDocumentBase
-from ikobacustom.skeleton.interfaces import MessageFactory as _
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomerDocument
+from ikobacustom.uniben.interfaces import MessageFactory as _
+from ikobacustom.uniben.customers.interfaces import ISkeletonCustomerDocument
 
 
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/fileviewlets.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/fileviewlets.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/fileviewlets.py	(revision 14178)
@@ -23,5 +23,5 @@
     FileDisplay, FileUpload, Image)
 
-from ikobacustom.skeleton.customers.documents import SkeletonCustomerDocument
+from ikobacustom.uniben.customers.documents import SkeletonCustomerDocument
 
 from waeup.ikoba.customers.browser import (
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/interfaces.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/interfaces.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/interfaces.py	(revision 14178)
@@ -24,5 +24,5 @@
     ConCatProductSource, CustomerDocumentSource)
 from waeup.ikoba.products.productoptions import ProductOptionField
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_browser.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/tests/test_browser.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_browser.py	(revision 14178)
@@ -30,13 +30,13 @@
 from waeup.ikoba.customers.tests.test_batching import CustomerImportExportSetup
 from waeup.ikoba.customers.tests.test_browser import CustomersFullSetup
-from ikobacustom.skeleton.customers.export import (
+from ikobacustom.uniben.customers.export import (
     SkeletonCustomerExporter,
     SkeletonCustomerDocumentExporter,
     SkeletonContractExporter)
-from ikobacustom.skeleton.customers.batching import (
+from ikobacustom.uniben.customers.batching import (
     SkeletonCustomerProcessor,
     SkeletonCustomerDocumentProcessor,
     SkeletonContractProcessor)
-from ikobacustom.skeleton.testing import FunctionalLayer, samples_dir
+from ikobacustom.uniben.testing import FunctionalLayer, samples_dir
 
 SAMPLE_IMAGE = os.path.join(os.path.dirname(__file__), 'test_image.jpg')
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_contract.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/tests/test_contract.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_contract.py	(revision 14178)
@@ -28,7 +28,7 @@
 from waeup.ikoba.customers.contracts import ContractsContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.customers.contracts import SkeletonContract
-from ikobacustom.skeleton.customers.interfaces import ISkeletonContract
+from ikobacustom.uniben.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.uniben.customers.contracts import SkeletonContract
+from ikobacustom.uniben.customers.interfaces import ISkeletonContract
 
 
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_customer.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/tests/test_customer.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_customer.py	(revision 14178)
@@ -17,5 +17,5 @@
 ##
 """
-Tests for skeleton customers.
+Tests for uniben customers.
 """
 import tempfile
@@ -30,7 +30,7 @@
 from waeup.ikoba.customers.container import CustomersContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.customers.customer import SkeletonCustomer
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomer
+from ikobacustom.uniben.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.uniben.customers.customer import SkeletonCustomer
+from ikobacustom.uniben.customers.interfaces import ISkeletonCustomer
 
 class SkeletonCustomerTestCase(FunctionalTestCase):
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_document.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/tests/test_document.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/tests/test_document.py	(revision 14178)
@@ -28,7 +28,7 @@
 from waeup.ikoba.customers.documents import CustomerDocumentsContainer
 
-from ikobacustom.skeleton.testing import (FunctionalLayer, FunctionalTestCase)
-from ikobacustom.skeleton.customers.documents import SkeletonCustomerDocument
-from ikobacustom.skeleton.customers.interfaces import ISkeletonCustomerDocument
+from ikobacustom.uniben.testing import (FunctionalLayer, FunctionalTestCase)
+from ikobacustom.uniben.customers.documents import SkeletonCustomerDocument
+from ikobacustom.uniben.customers.interfaces import ISkeletonCustomerDocument
 
 
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/utils.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/utils.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/utils.py	(revision 14178)
@@ -25,5 +25,5 @@
     SUBMITTED, VERIFIED, REJECTED,
     EXPIRED, PROVISIONALLY)
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.uniben.interfaces import MessageFactory as _
 
 class SkeletonCustomersUtils(CustomersUtils):
@@ -62,4 +62,4 @@
     EXPORTER_NAMES = (
         'customers',
-        'skeletoncustomerdocuments',
-        'skeletoncontracts')
+        'unibencustomerdocuments',
+        'unibencontracts')

Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/batching.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/batching.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/batching.py	(revision 14178)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Batch processing for skeleton documents.
 """
 import grok
@@ -22,8 +22,8 @@
     CustomerProcessor,
     CustomerDocumentProcessorBase, ContractProcessorBase)
-from ikobacustom.skeleton.customers.interfaces import (
+from ikobacustom.uniben.customers.interfaces import (
     ISkeletonCustomer,
     ISkeletonCustomerDocument, ISkeletonContract)
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.uniben.interfaces import MessageFactory as _
 
 
@@ -31,5 +31,5 @@
     """A batch processor for ICustomer objects.
     """
-    util_name = 'skeletoncustomerprocessor'
+    util_name = 'unibencustomerprocessor'
     grok.name(util_name)
     name = _('Skeleton Customer Processor')
@@ -40,5 +40,5 @@
     """A batch processor for ISkeletonCustomerDocument objects.
     """
-    util_name = 'skeletoncustomerdocumentprocessor'
+    util_name = 'unibencustomerdocumentprocessor'
     grok.name(util_name)
     name = _('Skeleton Customer Document Processor')
@@ -50,5 +50,5 @@
     """A batch processor for ISkeletonContract objects.
     """
-    util_name = 'skeletoncontractprocessor'
+    util_name = 'unibencontractprocessor'
     grok.name(util_name)
     name = _('Skeleton Customer Contract Processor')
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Batch processing for skeleton documents.
+"""Batch processing for uniben documents.
 """
 import grok
Index: main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/export.py
===================================================================
--- main/ikobacustom.uniben/trunk/src/ikobacustom/skeleton/customers/export.py	(revision 14174)
+++ main/ikobacustom.uniben/trunk/src/ikobacustom/uniben/customers/export.py	(revision 14178)
@@ -16,12 +16,12 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Exporters for skeleton customer objects and subobjects.
 """
 import grok
 from waeup.ikoba.customers.export import (
     CustomerExporter, CustomerDocumentExporterBase, ContractExporterBase)
-from ikobacustom.skeleton.customers.interfaces import (
+from ikobacustom.uniben.customers.interfaces import (
     ISkeletonCustomer, ISkeletonCustomerDocument, ISkeletonContractProcess)
-from ikobacustom.skeleton.interfaces import MessageFactory as _
+from ikobacustom.uniben.interfaces import MessageFactory as _
 
 class SkeletonCustomerExporter(CustomerExporter):
@@ -35,5 +35,5 @@
     """Exporter for documents.
     """
-    grok.name('skeletoncustomerdocuments')
+    grok.name('unibencustomerdocuments')
     iface = ISkeletonCustomerDocument
     title = _(u'Skeleton Customer Documents')
@@ -44,5 +44,5 @@
     """Exporter for Contract instances.
     """
-    grok.name('skeletoncontracts')
+    grok.name('unibencontracts')
     iface = ISkeletonContractProcess
     title = _(u'Skeleton Customer Contracts')
@@ -16,12 +16,12 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Exporters for skeleton customer objects and subobjects.
+"""Exporters for uniben customer objects and subobjects.
 """
 import grok